import 'dart:async';
import 'package:flutter/services.dart';

class Ed448Goldilock {
  static const MethodChannel _channel = const MethodChannel('ed448_goldilock');

  static Future<String> get generatePrivateKey async {
    final String privKey = await _channel.invokeMethod('generatePrivKey');
    return privKey;
  }

  static Future<String> getPublicKeyFromPrivateKey(String privateKey) async {
    final key =
        await _channel.invokeMethod('getPublicKey', {"key": privateKey});
    return key;
  }

  static Future<String> signWithPrivateKey(
      String privateKey, String msg) async {
    final signedString =
        await _channel.invokeMethod('sign', {"key": privateKey, "msg": msg});

    return signedString;
  }

  static Future<String> signWithPrivateKeyNConcatPubkey(
      String privateKey, String msg) async {
    final signedString = await _channel.invokeMethod(
        'concatenatedPubKeyWithSign', {"key": privateKey, "msg": msg});
    return signedString;
  }

  static Future<bool> verifySignature(
      String msgHash, String signedMsg, String pubKey) async {
    final result = await _channel.invokeMethod('verifySignature',
        {"msgHash": msgHash, "signedMsg": signedMsg, "pubKey": pubKey});
    return result;
  }
}
